# -*- coding:utf8 -*-
from flask import current_app, request

# use jwt module
import jwt

# get token with id and password
# return jwt token
# pass id and password parameters to authentification handler(auth_handler)
def process_login(id, pw):
	user = current_app.extensions['jwt'].auth_handler(id, pw)
	if user is None:
		return None

	token = jwt.encode(user.__dict__, \
		current_app.config["JWT_SECRET_KEY"], \
		algorithm=current_app.config["HASH_ALGORITHM"])

	return token

# get user info from request
def get_current_user():
	token = request.cookies.get(current_app.config["JWT_COOKIE_NAME"])
	if token is not None:
		try:
			jwt_token = jwt.decode(token, \
				current_app.config["JWT_SECRET_KEY"], \
				algorithms=[current_app.config['HASH_ALGORITHM']])
		except jwt.exceptions.DecodeError as e:
			# Signature verification failed
			jwt_token = None

		return jwt_token

	return None



# -*- coding: utf8 -*-
from flask import current_app, abort, request
from functools import wraps

from .config import DEFAULT_CONFIG 

import jwt

class JWT:
	# auth_handler: authentification handler
	# unauthorized: unauthorized handler
	def __init__(self, app=None):
		self.auth_handler = None
		self.unauthorized = None
		
		if app is not None:
			self.init_app(app)

	# Use secret key of flask app
	def init_app(self, app):
		# set default config
		for k, v in DEFAULT_CONFIG.items():
			app.config.setdefault(k, v)

		app.config.setdefault("JWT_SECRET_KEY", app.config["SECRET_KEY"])

		# register this class to flask extension
		app.extensions['jwt'] = self

	# register authenfication handler
	def authentication_handler(self, callback):
		self.auth_handler = callback
		return callback

	# register unauthorized handler
	def unauthorized_handler(self, callback):
		self.unauthorized = callback
		return callback

# login required decorator
def login_required(func):

	@wraps(func)
	def decorator(*args, **kwargs):
		jwt_login = current_app.extensions['jwt']
		
		token = request.cookies.get(current_app.config["JWT_COOKIE_NAME"])

		# token does not exist
		if token is None:
			if jwt_login.unauthorized is None:
				return abort(400)
			return jwt_login.unauthorized()

		try:
			jwt_token = jwt.decode(token, \
				current_app.config["JWT_SECRET_KEY"], \
				algorithms=[current_app.config['HASH_ALGORITHM']])
		except jwt.exceptions.DecodeError:
			if jwt_login.unauthorized is None:
				return abort(400)
			return jwt_login.unauthorized()
		# identity_handler does not exist
		return func(*args, **kwargs)

	return decorator



from setuptools import setup, find_packages

setup(
    name='Flask-JWT-Login',
    version='0.0.3',
    url='https://github.com/JeongUkJae/Flask-JWT-Login',
    license='MIT',
    author='Jeong Ukjae',
    author_email='jeongukjae@gmail.com',
    description='Flask extension that helps authentication using JWT',
    packages=find_packages(exclude=['tests']),
    zip_safe=False,
    test_suite='nose.collector',
    include_package_data=True,
    install_requires=[
        'click==6.7',
        'Flask==0.12.2',
        'itsdangerous==0.24',
        'Jinja2==2.9.6',
        'MarkupSafe==1.0',
        'PyJWT==1.5.3',
        'Werkzeug==0.12.2'
    ],
    tests_require=['nose'],
)